Attribute VB_Name = "Regions"
Option Explicit

Public Const RGN_AND = 1
Public Const RGN_OR = 2
Public Const RGN_XOR = 3
Public Const RGN_DIFF = 4
Public Const RGN_COPY = 5

Public Type POINTAPI
  X As Long
  Y As Long
End Type

Public Declare Function CreateRectRgn _
  Lib "gdi32" (ByVal X1 As Long, _
  ByVal Y1 As Long, _
  ByVal X2 As Long, _
  ByVal Y2 As Long) As Long

Public Declare Function CreatePolygonRgn _
  Lib "gdi32" (lpPoint As POINTAPI, _
  ByVal nCount As Long, _
  ByVal nPolyFillMode As Long) As Long

Public Declare Function CombineRgn _
  Lib "gdi32" (ByVal hDestRgn As Long, _
  ByVal hSrcRgn1 As Long, _
  ByVal hSrcRgn2 As Long, _
  ByVal nCombineMode As Long) As Long

Public Declare Function SetWindowRgn _
  Lib "user32" (ByVal hwnd As Long, _
  ByVal hRgn As Long, _
  ByVal bRedraw As Boolean) As Long

Public Declare Function GetPixel _
  Lib "gdi32" (ByVal hdc As Long, _
  ByVal X As Long, _
  ByVal Y As Long) As Long

Public Declare Function DeleteObject _
  Lib "gdi32" (ByVal hObject As Long) As Long


Public Function RegionFromImage( _
  picBackground As PictureBox, _
  ByVal lBackColor As Long) _
  As Long
  Dim hRegion As Long
  Dim lpicHeight As Long
  Dim lpicWidth As Long
  Dim lRow As Long
  Dim lCol As Long
  Dim lStart As Long
  Dim hTempRegion As Long
  Dim lResult As Long
  Dim lScaleM As Long

  lScaleM = picBackground.ScaleMode
  picBackground.ScaleMode = vbTwips
  'Initialize a rectangular region.
  hRegion = CreateRectRgn(0, 0, 0, 0)


  With picBackground
    'Determine image height and width in pixels
    lpicHeight = .Height / Screen.TwipsPerPixelY
    lpicWidth = .Width / Screen.TwipsPerPixelX

    'Scan the image one row at a time
    For lRow = 0 To lpicHeight - 1
      'Examine each pixel in the current row
      lCol = 0
      Do While lCol < lpicWidth
        'Look for the first pixel that
        'is NOT the background color
        Do While (lCol < lpicWidth) And _
          (GetPixel(.hdc, lCol, lRow) = lBackColor)
          lCol = lCol + 1
        Loop
        'Now that we have one that is NOT the background
        'color, look for the next one that IS the
        'background color. (This gives us a line of
        'foreground pixels.)
        If lCol < lpicWidth Then
          lStart = lCol
          Do While (lCol < lpicWidth) And _
            (GetPixel(.hdc, lCol, lRow) <> lBackColor)
            lCol = lCol + 1
          Loop
          If lCol > lpicWidth Then lCol = lpicWidth
          'Create a region using the line of                     'foreground pixels
          hTempRegion = CreateRectRgn(lStart, _
            lRow, _
            lCol, _
            lRow + 1)
          'Combine it with the existing region
          lResult = CombineRgn(hRegion, _
            hRegion, _
            hTempRegion, _
            RGN_OR)
          'Destroy the temporary region
          Call DeleteObject(hTempRegion)
        End If
      Loop
    Next lRow
  End With

  picBackground.ScaleMode = lScaleM

  'Return the region's handle
  RegionFromImage = hRegion

End Function



